searchData={"content_type":"text/markdown","items":[{"doc":"Plug for live-reload detection in development. Specifically, this plug\ninjects some Javascript at the bottom of each HTML page that listens to\nwebsocket events from `PlugLiveReload.Socket`. That Javascript will\nupdate the page.","ref":"PlugLiveReload.html","title":"PlugLiveReload","type":"module"},{"doc":"Add the `PlugLiveReload` plug to your router. E.g.,\n\n    defmodule MyApp.Router do\n      use Plug.Router\n\n      if Mix.env() == :dev do\n        plug PlugLiveReload\n      end\n\n      plug :match\n      plug :dispatch\n\n      get \"/\" do\n        conn\n        |> put_resp_content_type(\"text/html\")\n        |> send_resp(200, \"   Plug   \")\n      end\n    end\n\nThis plug will only inject the Javascript if the content type of the response is `text/html`.\nThis can be done with `Plug.Conn.put_resp_content_type/3`, as shown above.\n\nAdditionally, this plug will only inject Javascript if the HTML response\nhas a ` ` tag.","ref":"PlugLiveReload.html#module-usage","title":"Usage - PlugLiveReload","type":"module"},{"doc":"This plug is configured via opts passed to the plug. E.g.,\n\n    plug PlugLiveReload, target_window: :top\n\nThe following options are supported:\n\n  * `:iframe_attrs` - attrs to be given to the iframe injected by\n    live reload. Expects a keyword list of atom keys and string values.\n\n  * `:target_window` - the window that will be reloaded, as an atom.\n    Valid values are `:top` and `:parent`. An invalid value will\n    default to `:top`.\n\nAdditionally, one can disable the plug via an application config. This is\nuseful for disabling it dynamically when running a Mix task, for example.\nThis is typically not needed, as it is preferred to disable it via a\n`Mix.env()` guard check in your router, instead.\n\n    Application.put_env(:plug_live_reload, :disable_plug, true)","ref":"PlugLiveReload.html#module-configuration","title":"Configuration - PlugLiveReload","type":"module"},{"doc":"","ref":"PlugLiveReload.html#call/2","title":"PlugLiveReload.call/2","type":"function"},{"doc":"","ref":"PlugLiveReload.html#init/1","title":"PlugLiveReload.init/1","type":"function"},{"doc":"Cowboy socket handler that sends websocket events. This websocket is what\nthe `PlugLiveReload` plug's injected Javascript subscribes to in order\nto know when to reload.","ref":"PlugLiveReload.Socket.html","title":"PlugLiveReload.Socket","type":"module"},{"doc":"Add the `PlugLiveReload.Socket` to your `Plug.Cowboy` child spec.\n\n      def start(_type, _args) do\n        children = [\n          {Plug.Cowboy, scheme: :http, plug: MyApp.Router, options: [\n            port: 4000,\n            dispatch: dispatch()\n          ]}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n\n      if Mix.env() == :dev do\n        def dispatch(),\n          do: [\n            {:_,\n            [\n              {\"/plug_live_reload/socket\", PlugLiveReload.Socket, []},\n              {:_, Plug.Cowboy.Handler, {MyApp.Router, []}}\n            ]}\n          ]\n      else\n        def dispatch(), do: nil\n      end\n\nThis adds a new `:cowboy_websocket` handler for one route, `/plug_live_reload/socket`.\nAll other routes will continue to be handled as usual by your plug router. This also makes it\nso that handler is not added at all in the `:dev` environment.","ref":"PlugLiveReload.Socket.html#module-usage","title":"Usage - PlugLiveReload.Socket","type":"module"},{"doc":"This socket will only send events informing the page to reload if it the path of the changed\nresource matches any of the configured `:patterns`.\n\n      config :plug_live_reload,\n        patterns: [\n          ~r\"priv/static/.*(js|css|png|jpeg|jpg|gif|svg)$\",\n        ]\n\nThe configuration above will send an event if any of the JS/CSS/etc files in the `priv/static`\nchange.","ref":"PlugLiveReload.Socket.html#module-configuration","title":"Configuration - PlugLiveReload.Socket","type":"module"},{"doc":"# PlugLiveReload\n\nAdds live-reload functionality to [Plug](https://github.com/elixir-plug/plug) for development.","ref":"readme.html","title":"PlugLiveReload","type":"extras"},{"doc":"You can use `plug_live_reload` in your projects by adding it to your `mix.exs` dependencies:\n\n```\ndefp deps do\n [\n   {:plug_live_reload, \"~> 0.1.0\", only: :dev}\n ]\nend\n```\n\nOnce that is done, you will want to add the plug to your `Plug.Router`.\n\n```\ndefmodule MyApp.Router do\n  use Plug.Router\n\n  if Mix.env() == :dev do\n    plug PlugLiveReload\n  end\n  \n  plug :match\n  plug :dispatch\n\n  get \"/\" do\n    conn\n    |> put_resp_content_type(\"text/html\")\n    |> send_resp(200, \"   Plug   \")\n  end\nend\n```\n\nYou will additionally need to make sure the `PlugLiveReload.Socket` handler is added\nto your `Plug.Cowboy` child spec in your application.\n\n```\ndef start(_type, _args) do\n  children = [\n    {Plug.Cowboy, scheme: :http, plug: MyApp.Router, options: [\n      port: 4000,\n      dispatch: dispatch()\n    ]}\n  ]\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n\nif Mix.env() == :dev do\n  def dispatch(),\n    do: [\n      {:_,\n       [\n        {\"/plug_live_reload/socket\", PlugLiveReload.Socket, []},\n        {:_, Plug.Cowboy.Handler, {MyApp.Router, []}}\n       ]}\n    ]\nelse\n  def dispatch(), do: nil\nend\n```\n\nLastly, you will need to configure which file paths to watch.\n\n```\n# config/dev.exs\n\nconfig :plug_live_reload,\n  patterns: [\n    ~r\"priv/static/.*(js|css|png|jpeg|jpg|gif|svg)$\",\n  ]\n```\n\nYou can find additional documentation for configuring the `PlugLiveReload` plug and the `PlugLiveReload.Socket` \nin their respective documentation pages.","ref":"readme.html#installation","title":"Installation - PlugLiveReload","type":"extras"},{"doc":"This project uses [`FileSystem`](https://github.com/falood/file_system) as a dependency to watch your filesystem whenever there is a change and it supports the following operating systems:\n\n* Linux via [inotify](https://github.com/rvoicilas/inotify-tools/wiki) (installation required)\n* Windows via [inotify-win](https://github.com/thekid/inotify-win) (no installation required)\n* Mac OS X via fsevents (no installation required)\n* FreeBSD/OpenBSD/~BSD via [inotify](https://github.com/rvoicilas/inotify-tools/wiki) (installation required)\n\nThere is also a `:fs_poll` backend that polls the filesystem and is available on all Operating Systems in case you don't want to install any dependency. You can configure the `:backend` in your `config/config.exs`:\n\n```elixir\nconfig :plug_live_reload,\n  backend: :fs_poll\n```\n\nBy default the entire application directory is watched by the backend. However, with some environments and backends, this may be inefficient, resulting in slow response times to file modifications. To account for this, it's also possible to explicitly declare a list of directories for the backend to watch, and additional options for the backend:\n\n```elixir\nconfig :plug_live_reload,\n  dirs: [\n    \"priv/static\",\n    \"priv/gettext\",\n    \"lib/example_web/live\",\n    \"lib/example_web/views\",\n    \"lib/example_web/templates\",\n  ],\n  backend: :fs_poll,\n  backend_opts: [\n    interval: 500\n  ]\n```","ref":"readme.html#backends","title":"Backends - PlugLiveReload","type":"extras"},{"doc":"All stylesheets are reloaded without a page refresh anytime a style is detected as having changed. In certain cases such as serving stylesheets from a remote host, you may wish to prevent unnecessary reload of these stylesheets during development. For this, you can include a `data-no-reload` attribute on the link tag, ie:","ref":"readme.html#skipping-remote-css-reload","title":"Skipping remote CSS reload - PlugLiveReload","type":"extras"},{"doc":"Most of this code was adapted from [`phoenix_live_reload`](https://github.com/phoenix/phoenix_live_reload). \nThe main difference is that this package is plug-specific and takes no Phoenix dependencies.","ref":"readme.html#credits","title":"Credits - PlugLiveReload","type":"extras"}]}